<template>
    <el-dialog
        :visible.sync="annualInventoryVisible"
        append-to-body
        :title="title"
        :close-on-click-modal="false"
        width="1000px"
    >
        <el-form ref="dataForm" :rules="dataFormRules" :model="dataForm" label-position="right" label-width="140px"  >
            <el-form-item label="反馈内容:" prop="content">
                <el-input
                    class="textarea-input"
                    type="textarea"
                    :rows="2"
                    :disabled="disabledFlag"
                    placeholder="请输入内容"
                    v-model="dataForm.content">
                </el-input>
            </el-form-item>
            <el-form-item label="发现时间:" prop="findtime">
                <el-date-picker
                    value-format="yyyy-MM-dd"
                    v-model="dataForm.findtime"
                    :disabled="disabledFlag"
                    type="date"
                    placeholder="选择日期时间">
                </el-date-picker>
            </el-form-item>
            <el-form-item label="图片上传:" v-if="!disabledFlag" prop="imgs">1
                <el-upload
                    action="#"
                    ref="my-upload"
                    list-type="picture-card"
                    :on-remove="handleRemove"
                    :auto-upload="false"
                    :http-request="submitPermit"
                    :on-change="fileChange"
                    name="files">
                    <i class="el-icon-plus"></i>
                </el-upload>
                <el-dialog :visible.sync="dialogVisible">
                    <img width="100%" :src="dialogImageUrl" alt="">
                </el-dialog>

            </el-form-item>
            <el-form-item label="图片:" v-if="disabledFlag" prop="imgs">
                <el-image
                    class="upload-img"
                    v-for='item in imgUrls'
                    :key='item.id'
                    :src="item.url"
                    :preview-src-list="imgPreviewUrls"
                    style="width:200px;height: 200px;margin: 10px;"
                >
                </el-image>
            </el-form-item>
        </el-form>
        <div  align="right" v-show="!disabledFlag">
            <el-button @click="permitFormVisible = false">取消</el-button>
            <el-button type="primary" @click="submitPermit()">确认</el-button>
        </div>
    </el-dialog>

</template>

<script>
import {  addFeedBack , } from '@/api/Feed'
import {uploadUrl} from '@/assets/upload/url'

export default {
    name: "addAnnualInventory",
    data(){
        return{
            title:'',
            annualInventoryVisible:false,
            enterpriseId:'',
          file:'',
          fileList:[],
            dataForm:{
                content:'',
                enterpriseid:'',
                findtime:'',

            },
          imgUrls:[],
          imgPreviewUrls:[],
            dataFormRules:{},
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            dialogImageUrl: '',
            dialogVisible: false,
            disabled: false,
            uploadData:{
                enterprise:1
            },
          disabledFlag: false
        }
    },
    methods:{
        showFeedBack(title,value,enterpriseId){

            this.enterpriseId = enterpriseId
            this.annualInventoryVisible = true
            this.title = title
            if(this.title === '新增'){
              this.disabledFlag = false;
              this.dataForm = {
                content: '',
                findtime: ''
              }
            }
            //查看
            else{
                this.disabledFlag = true;
                this.dataForm.content = value.content
                this.dataForm.findtime = value.findtime
              this.imgUrls =value.enterpriseResources.map(item=>{
                return {
                  url: uploadUrl()+item.url,
                  name:item.id
                };

              })

              this.imgPreviewUrls = value.enterpriseResources.map(item=>{
                return uploadUrl() + item.url

              })
            }
        },

        async submitPermit(){

          let submitData = new FormData()
          //多文件
          for (let i = 0 ; i < this.fileList.length; i++) {
            submitData.append('file',this.fileList[i].raw)
          }
          submitData.append('enterpriseid',this.enterpriseId)
          submitData.append('content',this.dataForm.content)
          submitData.append('findtime',this.dataForm.findtime)
            if(this.title === '新增'){
                let res = await addFeedBack(submitData)
                if(res.data.code === "200"){

                    this.$emit('getinfo')
                    this.annualInventoryVisible = false
                    this.$notify({
                        type:'success',
                        duration:2000,
                        message:'成功',
                        title:'成功',
                    })
                }else {
                    this.$message({
                        type:'warning',
                        message:res.data.message
                    })
                }
              this.clearFiles()
            }else{
                let res = await updateAnnualInventory(this.dataForm)
                if(res.data.code === "200") {
                    this.$emit('getinfo')
                    this.annualInventoryVisible = false
                    this.$notify({
                        type: 'success',
                        duration: 2000,
                        message: '成功',
                        title: '成功',
                    })
                }
            }
        },

      handleRemove(file, fileList) {
        console.log(file, fileList);
      },

      fileChange:function(file,fileList){
        let fileName = file.name;
        let regex = /(.jpg|.jpeg|.gif|.png|.bmp)$/;
        if (!regex.test(fileName.toLowerCase())) {
          this.$message.error('请选择图片文件');
          return
        }
        this.file=file;
        this.fileList = fileList;
      },

      clearFiles () {
        this.$refs['my-upload'].clearFiles();
      }
    }
}
</script>

<style scoped>
/deep/ .el-input__inner {
    width: 300px;
}
.textarea-input{
    width: 320px;
}

    /deep/ .upload-img>img{
        border:1px solid #e2dfdf;
        border-radius: 3px;
    }
</style>
